On 12/16/19 11:11 PM, Richard Henderson wrote:
We don't actually need the result of the read, only to probe that the
memory mapping exists.  This is exactly what probe_access does.

This is also the only user of any cpu_ld*_code_ra function.
Removing this allows the interface to be removed shortly.

Acked-by: Max Filippov <[email protected]>
Signed-off-by: Richard Henderson <[email protected]>
---
  target/xtensa/mmu_helper.c | 5 +++--
  1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/target/xtensa/mmu_helper.c b/target/xtensa/mmu_helper.c
index f15bff306f..b01ff9399a 100644
--- a/target/xtensa/mmu_helper.c
+++ b/target/xtensa/mmu_helper.c
@@ -63,10 +63,11 @@
  void HELPER(itlb_hit_test)(CPUXtensaState *env, uint32_t vaddr)
  {
      /*
      * Attempt the memory load; we don't care about the result but
       * only the side-effects (ie any MMU or other exception)
       */
-    cpu_ldub_code_ra(env, vaddr, GETPC());
+    probe_access(env, vaddr, 1, MMU_INST_FETCH,
+                 cpu_mmu_index(env, true), GETPC());
@@ -63,10 +63,11 @@
  {
      /*
-     * Attempt the memory load; we don't care about the result but
+     * Probe the memory; we don't care about the result but
       * only the side-effects (ie any MMU or other exception)
       */

TIL probe_access

Reviewed-by: Philippe Mathieu-Daudé <[email protected]>

  }
void HELPER(wsr_rasid)(CPUXtensaState *env, uint32_t v)



Reply via email to